#!/usr/bin/env node
"use strict";
/*
 * MIT License
 *
 * Copyright (c) 2018 Choko (choko@curioswitch.org)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const util_1 = require("util");
const standalone_1 = __importDefault(require("@storybook/react/standalone"));
const rimraf_1 = __importDefault(require("rimraf"));
const webpack_sane_compiler_1 = __importDefault(require("webpack-sane-compiler"));
const webpack_sane_compiler_reporter_1 = __importDefault(require("webpack-sane-compiler-reporter"));
const prod_1 = require("../webpack/prod");
const check_1 = require("./check");
function runWebpack(config) {
    return __awaiter(this, void 0, void 0, function* () {
        const compiler = webpack_sane_compiler_1.default(config);
        webpack_sane_compiler_reporter_1.default(compiler);
        return compiler.run();
    });
}
function run() {
    return __awaiter(this, void 0, void 0, function* () {
        yield util_1.promisify(rimraf_1.default)(path_1.default.resolve(process.cwd(), 'build'));
        yield check_1.check();
        let result = yield runWebpack(prod_1.appConfiguration);
        if (result.stats.hasErrors()) {
            throw new Error();
        }
        if (prod_1.prerenderConfiguration) {
            result = yield runWebpack(prod_1.prerenderConfiguration);
            if (result.stats.hasErrors()) {
                throw new Error();
            }
        }
        const storybookConfigDir = path_1.default.resolve(process.cwd(), '.storybook');
        if (fs_1.default.existsSync(storybookConfigDir)) {
            yield standalone_1.default({
                mode: 'static',
                configDir: storybookConfigDir,
                outputDir: './build/storybook',
            });
        }
    });
}
if (require.main === module) {
    run()
        .then(() => process.exit(0))
        .catch((err) => {
        console.log('Error running webpack.', err);
        process.exitCode = 1;
    });
}
//# sourceMappingURL=build.js.map